@@ -5,7 +5,7 @@ print '''%s
         <title>Hello, word!</title>
     </head>
     <body>
-        <h1 align="center">Hello, World!</h1>
-        <p align="center">This is CGI Wrapper %s speaking...</p>
+        <h1 style="text-align:center">Hello, World!</h1>
+        <p style="text-align:center">This is CGI Wrapper %s speaking...</p>
     </body>
 </html>''' % (wrapper.docType(), wrapper.version())
