@@ -35,7 +35,7 @@ DOWNLOAD
 
 This script is part of Webware for Python.
 You can download the latest version from the GitHub repository
-(https://github.com/Cito/w4py/blob/master/DocSupport/autotoc.py).
+(https://github.com/WebwareForPython/w4py/blob/master/DocSupport/autotoc.py).
 
 
 COPYRIGHT
