@@ -26,9 +26,12 @@ class SQLiteObjectStore(SQLObjectStore):
     def dbVersion(self):
         return "SQLite %s" % sqlite.sqlite_version
 
-    def _executeSQL(self, cur, sql):
+    def _executeSQL(self, cur, sql, clausesArgs=None):
         try:
-            cur.execute(sql)
+            if clausesArgs is None:
+                cur.execute(sql)
+            else:
+                cur.execute(sql, clausesArgs)
         except sqlite.Warning:
             if not self.setting('IgnoreSQLWarnings', False):
                 raise
