@@ -1,10 +1,11 @@
 """TestCommon.py
 
 This is just a convenience module for the various test modules (TestFoo.py).
-
 """
 
-import os, sys, time
+import os
+import sys
+import time
 import FixPath
 import MiscUtils
 import MiddleKit
