@@ -1,5 +1,9 @@
-import os, time, socket
+import os
+import time
+import socket
+
 from marshal import dumps
+
 from MiscUtils.Configurable import Configurable
 
 
@@ -15,14 +19,15 @@ class Adapter(Configurable):
 
     def defaultConfig(self):
         return dict(
-            NumRetries = 20, # 20 retries when we cannot connect
-            SecondsBetweenRetries = 3, # 3 seconds pause between retries
-            ResponseBufferSize = 8*1024, # 8 kBytes
-            Host = 'localhost', # host running the app server
-            AdapterPort = 8086) # the default app server port
+            NumRetries = 20,  # 20 retries when we cannot connect
+            SecondsBetweenRetries = 3,  # 3 seconds pause between retries
+            ResponseBufferSize = 8*1024,  # 8 kBytes
+            Host = 'localhost',  # host running the app server
+            AdapterPort = 8086)  # the default app server port
 
     def configFilename(self):
-        return os.path.join(self._webKitDir, 'Configs', '%s.config' % self.name())
+        return os.path.join(
+            self._webKitDir, 'Configs', '%s.config' % self.name())
 
     def getChunksFromAppServer(self, env, myInput='',
             host=None, port=None):
@@ -30,7 +35,6 @@ class Adapter(Configurable):
 
         Used by subclasses that are communicating with a separate app server
         via socket. Yields the unmarshaled response in chunks.
-
         """
         if host is None:
             host = self.setting('Host')
@@ -53,13 +57,9 @@ class Adapter(Configurable):
             else:
                 break
         data = dumps(requestDict)
-        s.send(dumps(int(len(data))))
-        s.send(data)
-        sent = 0
-        inputLength = len(myInput)
-        while sent < inputLength:
-            chunk = s.send(myInput[sent:])
-            sent += chunk
+        s.sendall(dumps(int(len(data))))
+        s.sendall(data)
+        s.sendall(myInput)
         s.shutdown(1)
         bufsize = self.setting('ResponseBufferSize')
         while 1:
@@ -70,6 +70,7 @@ class Adapter(Configurable):
 
     def transactWithAppServer(self, env, myInput='', host=None, port=None):
         """Get the full response from the application server."""
+        self._respData[:] = []
         for data in self.getChunksFromAppServer(env, myInput, host, port):
             self.processResponse(data)
         return ''.join(self._respData)
