@@ -15,7 +15,7 @@ class AppControl(AdminSecurity):
                 wr('<p><b>You are running the <i>OneShot</i> version of WebKit.'
                     ' None of the options below are applicable.</b><p>')
             wr('''<form action="AppControl" method="post">
-<table cellspacing="4" cellpadding="4">
+<table>
 <tr><td><input type="submit" name="action" value="Shutdown"></td>
 <td>Shut down the AppServer. You need to restart it manually afterwards.</td>
 </tr><tr>
@@ -64,7 +64,7 @@ class AppControl(AdminSecurity):
                     wr("Reloading %s...<br>" % self.htmlEncode(str(m)))
                     try:
                         reload(m)
-                    except Exception, e:
+                    except Exception as e:
                         wr('<span style="color:red">Could not reload, '
                             'error was "%s".</span><br>' % e)
             wr('</p>')
