@@ -186,9 +186,8 @@ class ServletFactory(object):
                 if os.path.exists(initPy + ext):
                     break
             else:  # if it does not exist, make an empty one
-                file = open(initPy, 'w')
-                file.write('#')
-                file.close()
+                with open(initPy, 'w') as initPyFile:
+                    initPyFile.write('#')
         fp, pathname, stuff = self._imp.find_module(moduleName, [directory])
         module = self._imp.load_module(fullModuleName, fp, pathname, stuff)
         module.__donotreload__ = self._reloadClasses
@@ -222,8 +221,7 @@ class ServletFactory(object):
                 or mtime != self._classCache[path]['mtime']):
             # Use a lock to prevent multiple simultaneous
             # imports of the same module:
-            self._importLock.acquire()
-            try:
+            with self._importLock:
                 if (path not in self._classCache
                         or mtime != self._classCache[path]['mtime']):
                     theClass = self.loadClass(transaction, path)
@@ -232,8 +230,6 @@ class ServletFactory(object):
                             'mtime': mtime, 'class': theClass}
                 else:
                     theClass = self._classCache[path]['class']
-            finally:
-                self._importLock.release()
         else:
             theClass = self._classCache[path]['class']
 
@@ -257,8 +253,7 @@ class ServletFactory(object):
 
         # Use a lock to prevent multiple simultaneous imports of the same
         # module. Note that (only) the import itself is already threadsafe.
-        self._importLock.acquire()
-        try:
+        with self._importLock:
             mtime = os.path.getmtime(path)
             if path not in self._classCache:
                 self._classCache[path] = {
@@ -271,8 +266,6 @@ class ServletFactory(object):
             theClass = self._classCache[path]['class']
             if not self._cacheClasses:
                 del self._classCache[path]
-        finally:
-            self._importLock.release()
 
         # No adequate cached servlet exists, so create a new servlet instance
         servlet = theClass()
