@@ -21,5 +21,5 @@ class DebugPage(Page):
         return '\n'.join(rv)
 
     def writeContent(self):
-        self.writeln('<h2><tt>%s</tt></h2>' % self.__class__.__name__)
+        self.writeln('<h2><code>%s</code></h2>' % self.__class__.__name__)
         self.writeln('<pre>%s</pre>' % self.state())
