@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 
 """Threaded Application Server
 
@@ -388,7 +388,7 @@ class ThreadedAppServer(AppServer):
 
                     try:
                         client, addr = sock.accept()
-                    except select.error as e:
+                    except socket.error as e:
                         if e[0] not in self._ignoreErrnos:
                             raise
                         if debug:
